@@ -66,16 +66,25 @@ def sagemaker_env_args(args: argparse.Namespace, config: SageMakerTrainingConfig
         ci = data.get('channel_input_dirs', None)
         if ci:
             for k in config.inputs.keys():
-                v = ci.get(k, None)
-                if v:
-                    suffix = kwargs.get('{}_suffix'.format(k), None)
-                    if suffix and os.path.exists(v):
-                        # todo: handle file pipes
-                        v = os.path.join(v, suffix)
-                    print("SageMaker input [{}]: [{}]".format(k, v))
+                mode = kwargs["{}_mode".format(k)]
+                if mode in ['ManifestFolder','AugmentedManifestFolder']:
+                    v = {}
+                    for ik, iv in ci.items():
+                        if ik.startswith("{}_".format(k)):
+                            v[ik[len(k)+1:]]=iv
+                            kwargs[ik] = iv
                     kwargs[k] = v
                 else:
-                    kwargs[k] = None
+                    v = ci.get(k, None)
+                    if v:
+                        suffix = kwargs.get('{}_suffix'.format(k), None)
+                        if suffix and os.path.exists(v):
+                            # todo: handle file pipes
+                            v = os.path.join(v, suffix)
+                        print("SageMaker input [{}]: [{}]".format(k, v))
+                        kwargs[k] = v
+                    else:
+                        kwargs[k] = None
         else:
             for k in config.inputs.keys():
                 kwargs[k] = None
@@ -131,7 +140,8 @@ def sagemaker_training_args(
     volume_size=30,
     max_run=60*60*12,
     max_wait=60*60*24,
-    env=None
+    env=None,
+    workers=2
 ):
     r"""
     Configure ``argparse.ArgumentParser`` for training scripts.
@@ -217,6 +227,8 @@ def sagemaker_training_args(
         Maximum training time in seconds.
     max_wait : int, optional
         Maximum time to wait for a spot instance in seconds.
+    workers : int, optional
+        Number of workers
     """
     if isinstance(script, types.FunctionType):
         script = inspect.getfile(script)
