@@ -11,6 +11,11 @@ from ..tags import make_tags
 from ..s3 import get_file_type, FileType
 from sagemaker.inputs import TrainingInput
 import warnings
+from ..args import get_mode, get_s3_data_type
+import tempfile
+from urllib.parse import urlparse
+from ..util.pipes import chunk_iterable
+from sagemaker.s3 import S3Uploader
 
 
 def sagemaker_training_run(
@@ -93,25 +98,67 @@ def sagemaker_training_run(
                 del hyperparameters[key]
         else:
             raise ValueError()
-    
-    channels = {
-        k: TrainingInput(
-            s3_data=v,
-            # distribution=None,
-            # compression=None,
-            # content_type=None,
-            # record_wrapping=None,
-            # s3_data_type="S3Prefix",
-            input_mode=getattr(args, "{}_mode".format(k)) or "File"
-            # attribute_names=None,
-            # target_attribute_name=None,
-            # shuffle_config=None,
-        ) for k, v in channels.items()
-    }
+
+    chs = {}
+    for k, v in channels.items():
+        mode = getattr(args, "{}_mode".format(k))
+        if (
+            mode in [
+                'AugmentedManifestFolder',
+                'ManifestFolder'
+            ]
+        ):
+            uri = urlparse(v)
+            assert uri.scheme == 's3'
+            bucket = uri.netloc
+            key = uri.path.lstrip("/").rstrip("/")+"/"
+            manifests = s3.list_objects_v2(
+                Bucket=bucket,
+                # Delimiter='string',
+                # EncodingType='url',
+                # MaxKeys=123,
+                Prefix=key,
+                # ContinuationToken='string',
+                # FetchOwner=True|False,
+                # StartAfter='string',
+                # RequestPayer='requester',
+                # ExpectedBucketOwner='string'
+            )
+            for manifest in manifests['Contents']:
+                mkey = manifest['Key'].lstrip('/')
+                bn,_ = os.path.splitext(os.path.basename(mkey))
+                s3_data="s3://{}/{}".format(bucket, mkey)
+                chs["{}_{}".format(k, bn.replace("-", "_"))] = TrainingInput(
+                    s3_data=s3_data,
+                    record_wrapping="RecordIO",
+                    s3_data_type=get_s3_data_type(mode),
+                    input_mode=get_mode(mode),
+                    attribute_names=config.inputs[k].attributes
+                )
+                print("Adding manifest [{}] to input [{}]".format(s3_data, k))
+        elif mode in [
+            'File','Pipe','ManifestFile','AugmentedManifestFile'
+        ]:
+            chs[k] = TrainingInput(
+                s3_data=v,
+                # distribution=None,
+                # compression=None,
+                # content_type=None,
+                record_wrapping="RecordIO" if get_mode(mode) in ['Pipe'] else None,
+                s3_data_type=get_s3_data_type(mode),
+                input_mode=get_mode(mode),
+                attribute_names=config.inputs[k].attributes
+                # target_attribute_name=None,
+                # shuffle_config=None,
+            )
+        else:
+            raise ValueError("Unknown mode: {}->{}".format(k, mode))
+    channels = chs
     print("Hyperparameters: {}".format(hyperparameters))
 
     if not channels:
         channels = None
+    print("Channels: {}".format(channels))
     #env = config.env
 
     estimator = PyTorch(
